AppGradients class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- danger → const LinearGradient
- dark → const LinearGradient
- emerald → const LinearGradient
- gold → const LinearGradient
- horizontalGradients → const LinearGradient
- instagram → const LinearGradient
- ocean → const LinearGradient
- primary → const LinearGradient
- purpleLove → const LinearGradient
- radialBlue → const RadialGradient
- radialDark → const RadialGradient
- rainbow → const SweepGradient
- sky → const LinearGradient
- success → const LinearGradient
- sunset → const LinearGradient
- warning → const LinearGradient