ApiHandlerHttp class

Constructors

ApiHandlerHttp({required String baseUrl, String authToken = '', Client? client})

Properties

authToken String
final
baseUrl String
final
client → Client
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(String endpoint, {required T fromJson(Map<String, dynamic>), Map<String, dynamic>? queryParameters}) Future<T>
getList<T>(String endpoint, {required T fromJson(Map<String, dynamic>), Map<String, dynamic>? queryParams}) Future<List<T>>
getRaw(String endpoint, {Map<String, dynamic>? queryParameters}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post<T>(String endpoint, {required dynamic data, required T fromJson(Map<String, dynamic>)}) Future<T>
postBytes(String endpoint, {required Map<String, dynamic> data}) Future<List<int>>
postRaw<T>(String endpoint, {required dynamic data, required T fromJson(dynamic)}) Future<(int?, String?, T)>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited