UiScheduler class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cancel(
Timer? timer) → void -
run(
VoidCallback callback) → void - Immediate execution (like Handler.post)
-
runDelayed(
Duration delay, VoidCallback callback) → Future< void> - Delayed execution (like Handler.postDelayed)
-
runPeriodic(
Duration interval, VoidCallback callback) → Timer - Repeating task